@@ -1240,8 +1240,7 @@ protected:
         {
             osg::ref_ptr< Observer > observer = itr->get();
             ImGui::PushID(observer.get());
-            ImGui::Text("%s", observer->getName().c_str());
-            ImGui::SameLine();
+            ImGui::Text(observer->getName().c_str()); ImGui::SameLine();
             if (ImGui::Button("Delete"))
             {
                 observers.erase(itr);
