@@ -618,12 +618,12 @@ ArcGISServerImageLayer::createImageImplementation(const TileKey& key, ProgressCa
     }
 
     //Add the layers if necessary
-    if (!options().layers()->empty())
+    if (!_layers.empty())
     {
         std::string str;
         str = buf.str();
         std::string sep = str.find('?') == std::string::npos ? "?" : "&";
-        buf << sep << "layers=show:" << options().layers().value();
+        buf << sep << "layers=show:" << _layers;
     }
 
     std::string bufStr;
