@@ -313,7 +313,6 @@ GeometryCompiler::compile(FeatureList&          workingSet,
     }
 
     // resample the geometry if necessary:
-    // @deprecated, remove this, dupe of the ResampleFilter
     if (_options.resampleMode().isSet())
     {
         ResampleFilter resample;
@@ -326,7 +325,7 @@ GeometryCompiler::compile(FeatureList&          workingSet,
         if ( trackHistory ) history.push_back( "resample" );
     }
 
-    // check whether we need to do elevation adjustment:
+    // check whether we need to do elevation clamping:
     bool altRequired =
         _options.ignoreAltitudeSymbol() != true &&
         altitude && (
@@ -335,7 +334,7 @@ GeometryCompiler::compile(FeatureList&          workingSet,
             altitude->verticalScale().isSet() ||
             altitude->script().isSet() );
 
-    // instance substitution:
+    // instance substitution (replaces marker)
     if ( model )
     {
         const InstanceSymbol* instance = (const InstanceSymbol*)model;
@@ -412,7 +411,10 @@ GeometryCompiler::compile(FeatureList&          workingSet,
             extrude.setFeatureNameExpr( *_options.featureName() );
 
         if (_options.mergeGeometry().isSet())
-            extrude.setMergeGeometry(*_options.mergeGeometry());            
+            extrude.setMergeGeometry(*_options.mergeGeometry());
+        //else if (_options.optimize() == true)
+        //    extrude.setMergeGeometry(false);
+            
 
         osg::Node* node = extrude.push( workingSet, sharedCX );
         if ( node )
@@ -420,6 +422,7 @@ GeometryCompiler::compile(FeatureList&          workingSet,
             if ( trackHistory ) history.push_back( "extrude" );
             resultGroup->addChild( node );
         }
+
     }
 
     // simple geometry
@@ -487,11 +490,6 @@ GeometryCompiler::compile(FeatureList&          workingSet,
         }
     }
 
-    if (render)
-    {
-        render->applyTo(resultGroup.get());
-    }
-
     if (Registry::capabilities().supportsGLSL())
     {
         ShaderPolicy shaderPolicy = _options.shaderPolicy().get();
