@@ -181,13 +181,11 @@ namespace osgEarth
                     }
                     else
                     {
-                        auto tokens = StringTokenizer()
-                            .delim(":")
-                            .standardQuotes()
-                            .tokenize(line);
-
-                        if (tokens.size() >= 2 )
-                            next_part->_headers[tokens[0]] = tokens[1];
+                        StringTokenizer tok(":");
+                        StringVector tized;
+                        tok.tokenize(line, tized);
+                        if ( tized.size() >= 2 )
+                            next_part->_headers[tized[0]] = tized[1];
                     }
                 }
             }
@@ -223,31 +221,6 @@ namespace osgEarth
 
         return true;
     }
-
-    void setMetadata(ReadResult& result, const HTTPRequest& request, const HTTPResponse& response)
-    {
-        // be sure to install the response headers at the top level:
-        Config meta = response.getHeadersAsConfig();
-        meta.key() = "HTTP GET";
-
-        auto& r = meta.add("osgEarth Request");
-        
-        r.add("URI", request.getURL());
-
-        if (response.getCode() == 0)
-        {
-            if (!response.getMessage().empty())
-                r.add("Request Error", response.getMessage());
-            else
-                r.add("Request Error (UNKNOWN)");
-        }
-        else
-        {
-            r.add("HTTP Response Code", std::to_string(response.getCode()));
-            r.add("HTTP Request Headers", request.getHeadersAsConfig());
-        }
-        result.setMetadata(meta);
-    }
 }
 
 /****************************************************************************/
@@ -317,16 +290,6 @@ HTTPRequest::getHeaders()
     return _headers;
 }
 
-Config
-HTTPRequest::getHeadersAsConfig() const
-{
-    Config conf("HTTP Request Headers");
-    for (auto& header : _headers)
-        conf.add(header.first, header.second);
-    return conf;
-
-}
-
 void HTTPRequest::setLastModified( const DateTime &lastModified)
 {
     addHeader("If-Modified-Since", lastModified.asRFC1123());
@@ -437,11 +400,13 @@ HTTPResponse::getMimeType() const {
 Config
 HTTPResponse::getHeadersAsConfig() const
 {
-    Config conf("HTTP Response Headers");
+    Config conf;
     if ( _parts.size() > 0 )
     {
-        for(auto& header : _parts[0]->_headers)
-            conf.add(header.first, header.second);
+        for( Headers::const_iterator i = _parts[0]->_headers.begin(); i != _parts[0]->_headers.end(); ++i )
+        {
+            conf.set(osgEarth::toLower(i->first), i->second);
+        }
     }
     return conf;
 }
@@ -743,7 +708,6 @@ namespace
                 // CURLE_ABORTED_BY_CALLBACK means ProgressCallback cancelation.
                 HTTPResponse response;
                 response.setCanceled(true);
-                response.setMessage(std::string(curl_easy_strerror(res)));
                 return response;
             }
 
@@ -753,8 +717,7 @@ namespace
                 CURLcode r = curl_easy_getinfo(_curl_handle, CURLINFO_HTTP_CONNECTCODE, &connect_code);
                 if ( r != CURLE_OK )
                 {
-                    std::string msg = "Proxy connect error   " + std::string(curl_easy_strerror(r));
-                    OE_WARN << LC << msg << std::endl;
+                    OE_WARN << LC << "Proxy connect error: " << curl_easy_strerror(r) << std::endl;
 
                     // Free the headers
                     if (headers)
@@ -762,9 +725,7 @@ namespace
                         curl_slist_free_all(headers);
                     }
 
-                    HTTPResponse response(0);
-                    response.setMessage(msg);
-                    return response;
+                    return HTTPResponse(0);
                 }
             }
 
@@ -813,7 +774,7 @@ namespace
                 {
                     for (Headers::iterator itr = sp._headers.begin(); itr != sp._headers.end(); ++itr)
                     {
-                        part->_headers[Strings::trim(itr->first)] = Strings::trim(itr->second);
+                        part->_headers[itr->first] = itr->second;
                     }
 
                     // Write the headers to the metadata
@@ -1759,7 +1720,7 @@ HTTPClient::doReadImage(const HTTPRequest&    request,
         if (!reader)
         {
             result = ReadResult(ReadResult::RESULT_NO_READER);
-            result.setErrorDetail("Content-Type=" + response.getMimeType());
+            result.setErrorDetail(Stringify() << "Content-Type=" << response.getMimeType());
         }
 
         else
@@ -1843,9 +1804,8 @@ HTTPClient::doReadImage(const HTTPRequest&    request,
         }
     }
 
-    // encode metadata
-    setMetadata(result, request, response);
-
+    // encode headers
+    result.setMetadata( response.getHeadersAsConfig() );
     result.setIsFromCache(response.getFromCache());
 
     // set the source name
@@ -1921,11 +1881,6 @@ HTTPClient::doReadNode(const HTTPRequest&    request,
             {
                 OE_WARN << LC << "SERVER REPORTS: " << result.errorDetail() << std::endl;
             }
-
-            if (s_HTTP_DEBUG)
-            {
-                OE_WARN << LC << "SERVER REPORTS: " << result.errorDetail() << std::endl;
-            }
         }
 
         //If we have an error but it's recoverable, like a server error or timeout then set the callback to retry.
@@ -1951,10 +1906,8 @@ HTTPClient::doReadNode(const HTTPRequest&    request,
         }
     }
 
-
-    // encode metadata
-    setMetadata(result, request, response);
-
+    // encode headers
+    result.setMetadata( response.getHeadersAsConfig() );
     result.setIsFromCache(response.getFromCache());
 
     return result;
@@ -2027,11 +1980,6 @@ HTTPClient::doReadObject(const HTTPRequest&    request,
             {
                 OE_WARN << LC << "SERVER REPORTS: " << result.errorDetail() << std::endl;
             }
-
-            if (s_HTTP_DEBUG)
-            {
-                OE_WARN << LC << "SERVER REPORTS: " << result.errorDetail() << std::endl;
-            }
         }
 
         //If we have an error but it's recoverable, like a server error or timeout then set the callback to retry.
@@ -2057,8 +2005,7 @@ HTTPClient::doReadObject(const HTTPRequest&    request,
         }
     }
 
-    // encode metadata
-    setMetadata(result, request, response);
+    result.setMetadata( response.getHeadersAsConfig() );
 
     return result;
 }
@@ -2095,7 +2042,7 @@ HTTPClient::doReadString(const HTTPRequest&    request,
 
             if (s_HTTP_DEBUG)
             {
-                OE_WARN << LC << "SERVER REPORTS: " << result.errorDetail() << std::endl;
+                OE_NOTICE << LC << "SERVER REPORTS: " << result.errorDetail() << std::endl;
             }
         }
 
@@ -2122,9 +2069,8 @@ HTTPClient::doReadString(const HTTPRequest&    request,
         }
     }
 
-    // encode metadata
-    setMetadata(result, request, response);
-
+    // encode headers
+    result.setMetadata( response.getHeadersAsConfig() );
     result.setIsFromCache(response.getFromCache());
 
     // last-modified (file time)
