@@ -278,7 +278,7 @@ ImageLayer::setAltitude(const Distance& value)
 {
     options().altitude() = value;
 
-    if (value.getValue() != 0.0)
+    if (value != 0.0)
     {
         osg::StateSet* stateSet = getOrCreateStateSet();
 
@@ -696,7 +696,7 @@ ImageLayer::assembleImage(const TileKey& key, ProgressCallback* progress)
 
             // Working set of points. it's much faster to xform an entire vector all at once.
             std::vector<osg::Vec3d> points;
-            points.resize(cols * rows);
+            points.assign(cols * rows, { 0, 0, 0 });
 
             double minx, miny, maxx, maxy;
             key.getExtent().getBounds(minx, miny, maxx, maxy);
@@ -704,21 +704,14 @@ ImageLayer::assembleImage(const TileKey& key, ProgressCallback* progress)
             double dy = (maxy - miny) / (double)(rows);
 
             Bounds sourceBounds;
-            auto sourceSRS = sources[0].second.getSRS();
-            sourceSRS->getBounds(sourceBounds);
-
-            // Transform the source bounds and shrink it by our pixel-centering value:
+            sources[0].second.getSRS()->getBounds(sourceBounds);
+            // shrink the sourceBounds by our pixel-centering value:
             if (sourceBounds.valid())
             {
-                sourceSRS->clampExtentToLegalBounds(key.getProfile()->getSRS(),
-                    sourceBounds.xMin(), sourceBounds.yMin(),
-                    sourceBounds.xMax(), sourceBounds.yMax());
-
-                // revisit this if necessary - it was being applied in the wrong SRS
-                //sourceBounds.xMin() += 0.5 * dx;
-                //sourceBounds.yMin() += 0.5 * dy;
-                //sourceBounds.xMax() -= 0.5 * dx;
-                //sourceBounds.yMax() -= 0.5 * dy;
+                sourceBounds.xMin() += 0.5 * dx;
+                sourceBounds.yMin() += 0.5 * dy;
+                sourceBounds.xMax() -= 0.5 * dx;
+                sourceBounds.yMax() -= 0.5 * dy;
             }
 
             // build a grid of sample points:
