@@ -24,7 +24,6 @@
 #include <osgEarth/TileKey>
 #include <osgEarth/TerrainEngineNode>
 #include <osgEarth/TerrainResources>
-#include <osgEarth/NetworkMonitor>
 #include <osg/StateSet>
 
 using namespace osgEarth;
@@ -353,8 +352,6 @@ Layer::open()
         return getStatus();
     }
 
-    NetworkMonitor::ScopedRequestLayer layerRequest(getName());
-
     // be optimistic :)
     _status.set(Status::NoError);
 
