@@ -168,8 +168,7 @@ SDFGenerator::createNearestNeighborField(
         style.getOrCreate<PolygonSymbol>()->fill().mutable_value().color() = Color::Black;
 
     FeatureRasterizer rasterizer(nnfieldSize, nnfieldSize, extent, Color(1, 1, 1, 0));
-    FilterContext context;
-    rasterizer.render(features, style, context);
+    rasterizer.render(features, style);
     GeoImage source = rasterizer.finalize();
 
     return createNearestNeighborField(
