@@ -533,7 +533,7 @@ namespace
 
         //osg::Timer_t startTime = osg::Timer::instance()->tick();
 
-        unsigned long handle = NetworkMonitor::begin(inputURI.full(), "Pending", inputURI.isRemote() ? "Network" : "File");
+        unsigned long handle = NetworkMonitor::begin(inputURI.full(), "pending", "URI");
         ReadResult result;
 
         if (osgEarth::Registry::instance()->isBlacklisted(inputURI.full()))
@@ -694,22 +694,13 @@ namespace
             (*post)(result);
         }
 
-        auto msg = result.getResultCodeString();
-
+        std::stringstream buf;
+        buf << result.getResultCodeString();
         if (result.isFromCache() && result.succeeded())
         {
-            msg = "Cache";
+            buf << " (from cache)";
         }
-
-        std::string details;
-
-        if (!result.metadata().empty())
-            details += result.metadata().toJSON(true);
-
-        if (!result.errorDetail().empty())
-            details += result.errorDetail();
-
-        NetworkMonitor::end(handle, msg, details);
+        NetworkMonitor::end(handle, buf.str());
 
         return result;
     }
