@@ -137,10 +137,9 @@ namespace
         Config libraries = conf.child("libraries");
         if (!libraries.value().empty())
         {
-            auto libs = StringTokenizer()
-                .delim(";")
-                .tokenize(libraries.value());
-
+            StringTokenizer izer( ";" );
+            StringVector libs;
+            izer.tokenize( libraries.value(), libs );
             for (StringVector::iterator itr = libs.begin(); itr != libs.end(); ++itr)
             {
                 std::string lib = *itr;
